CelestialObjectsLayer class

  1. Celestial Objects Layer: Black Hole or Wormhole rendering.
Inheritance

Constructors

CelestialObjectsLayer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
priority int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas, Size size, UniverseContext context, UniverseScene scene) → void
Draw the layer content on the canvas.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited